package cz.kebrt.unitcheck.api.data;

/**
 * Base class of all failures. Holds description of a failure, execution trace leading to
 * the failure, and a the state of all threads at the moment of the failure.
 */
public abstract class Failure implements CheckResult {

    private final Description description;
    private final PathHolder path;
    private final String snapShot;

    /**
     * Constructs an instance.
     * @param description description of the failure
     * @param path execution trace leading to the failure
     * @param snapShot state of all threads at the moment of the failure
     */
    public Failure(Description description, PathHolder path, String snapShot) {
        super();
        this.description = description;
        this.path = path;
        this.snapShot = snapShot;
    }

    /**
     * Returns description of the failure.
     * @return description of the failure
     */
    public Description getDescription() {
        return description;
    }

    @Override
    public boolean isSuccessful() {
        return false;
    }

    /**
     * Returns execution trace leading to the failure.
     * @return execution trace leading to the failure
     */
    public PathHolder getPath() {
        return path;
    }

    /**
     * Returns state of all threads at the moment of the failure.
     * @return state of all threads at the moment of the failure
     */
    public String getSnapShot() {
        return snapShot;
    }

}
