package cz.kebrt.unitcheck.junit.holder;

/**
 * Holds summary information about running a set of tests. Dual to JUnit
 * <code>Result</code> class.
 */
public class TestRunResult {

    private final boolean successful;
    private final int runCount;
    private final int ignoreCount;
    private final int failureCount;
    private final long runTime;

    /**
     * Constructs an instance.
     *
     * @param successful <code>true</code> if all tests succeeded
     * @param runCount  the number of tests run
     * @param ignoreCount the number of tests ignored during the run
     * @param failureCount the number of tests that failed during the run
     * @param runTime the number of milliseconds it took to run the entire suite to run
     */
    public TestRunResult(boolean successful, int runCount, int ignoreCount,
            int failureCount, long runTime) {
        super();
        this.successful = successful;
        this.runCount = runCount;
        this.ignoreCount = ignoreCount;
        this.runTime = runTime;
        this.failureCount = failureCount;
    }

    /**
     * Returns the number of tests ignored during the run.
     * @return the number of tests ignored during the run
     */
    public int getIgnoreCount() {
        return ignoreCount;
    }

    /**
     * Returns the number of milliseconds it took to run the entire suite to run.
     * @return the number of milliseconds it took to run the entire suite to run
     */
    public long getRunTime() {
        return runTime;
    }

    /**
     * Returns  the number of tests run.
     * @return the number of tests run
     */
    public int getRunCount() {
        return runCount;
    }

    /**
     * Returns the number of tests that failed during the run.
     * @return the number of tests that failed during the run
     */
    public int getFailureCount() {
        return failureCount;
    }

    /**
     * Returns <code>true</code> if all tests succeeded.
     * @return <code>true</code> if all tests succeeded
     */
    public boolean isSuccessful() {
        return successful;
    }

}
