package cz.kebrt.unitcheck.ant;

import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.tools.ant.types.FileSet;
import org.apache.tools.ant.types.Resource;
import org.apache.tools.ant.types.ResourceCollection;
import org.apache.tools.ant.types.resources.Resources;

import cz.kebrt.unitcheck.config.ConfigException;
import cz.kebrt.unitcheck.config.TestConfig;

/**
 * Represents Ant configuration of a batch test.
 *
 * @author michal
 */
public class BatchTest {

    private static final String CLASS_SUFFIX = ".class";
    private static final String JAVA_SUFFIX = ".java";

    private Resources resources = new Resources();

    /**
     * Returns list of UnitCheck configurations of input tests.
     * @return list of UnitCheck configurations of input tests
     *
     * @throws ConfigException some test could not be found
     */
    public List<TestConfig> createTests() throws ConfigException {
        List<TestConfig> tests = new ArrayList<TestConfig>();
        for (Iterator<?> it = resources.iterator(); it.hasNext();) {
            Resource r = (Resource) it.next();
            if (r.isExists()) {
                String pathname = r.getName();
                if (pathname.endsWith(JAVA_SUFFIX)) {
                    pathname = pathname.substring(0, pathname.length()
                            - JAVA_SUFFIX.length());
                } else if (pathname.endsWith(CLASS_SUFFIX)) {
                    pathname = pathname.substring(0, pathname.length()
                            - CLASS_SUFFIX.length());
                }
                tests.add(new TestConfig(pathToClass(pathname)));
            }
        }
        return tests;
    }

    private String pathToClass(String filename) {
        return filename.replace(File.separatorChar, '.').replace('/', '.').replace('\\',
                '.');
    }

    // =================================================================================
    // The following methods correspond to elements and attributes supported by the task
    // =================================================================================

    /**
     * Add a new fileset instance to this batch test. Whatever the fileset is, only
     * filename that are <tt>.java</tt> or <tt>.class</tt> will be considered as
     * 'candidates'.
     *
     * @param fileset the new fileset containing the rules to get the test cases
     */
    public void addFileset(FileSet fileset) {
        add(fileset);
    }

    /**
     * Add a new ResourceCollection instance to this batch test. Whatever the collection
     * is, only names that are <tt>.java</tt> or <tt>.class</tt> will be considered as
     * 'candidates'.
     *
     * @param rc the new ResourceCollection containing the rules to get the test cases.
     */
    public void add(ResourceCollection rc) {
        resources.add(rc);
    }

}
